@@ -3,8 +3,35 @@ import os
 import subprocess
 import time
 import urllib.request
-from urllib.parse import urlparse
-from src.utilities import display
+from src.utilities import display, send_message_to_slack as sml
+import socket
+
+
+def port_check(args):
+    hostname = args.hostname
+    surname = args.surname
+    port = args.port
+
+    a_socket = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
+    a_socket.settimeout(3)
+
+    location = (hostname, port)
+    result_of_check = a_socket.connect_ex(location)
+    a_socket.close()
+
+    if args.message:
+        message = args.message.format(hostname=hostname, surname=surname, port=port)
+    else:
+        message = f"Port {port} of {hostname}/{surname} is accessible: Yes"
+
+    if result_of_check == 0:
+        display(message=message)
+        return True
+    else:
+        message = message.replace("Yes", "No")
+        display(message=message)
+        sml(message=message)
+        return False
 
 
 def check_ping(hostname):
@@ -34,18 +61,28 @@ def ping_test(args):
 
     percentage = int((counter / how_many_check) * 100)
 
+    if args.message:
+        message = args.message.format(hostname=hostname, surname=surname)
+    else:
+        message = f"Ping check to {hostname}/{surname} is ok: Yes"
+
     if percentage < threshold:
-        message = f"Ping check failed at '{surname}: {hostname}'."
+        message = message.replace("Yes", "No")
         display(message=message)
+        sml(message=message)
     else:
-        message = f"Ping check passed at '{surname}: {hostname}'."
         display(message=message)
 
 
 def string_check(args):
     url = args.url
+    surname = args.surname
     string = args.string
-    message = f"Found '{string}' at {url}"
+
+    if args.message:
+        message = args.message.format(url=url, surname=surname, string=string)
+    else:
+        message = f"String - {string} found in {url} -- {surname}: Yes"
 
     req = urllib.request.Request(url)
     req.add_header(
@@ -53,51 +90,14 @@ def string_check(args):
         'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_7) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/98.0.4758.102 Safari/537.36')
     with urllib.request.urlopen(req) as response:
         the_page = response.read()
+        chk = string.lower() in the_page.decode("utf-8").lower()
+        print(the_page.decode("utf-8").lower())
         if string.lower() in the_page.decode("utf-8").lower():
             display(message=message)
             return True
         else:
-            display(message=message.replace("Found", "Not Found"))
-            return False
-
-
-def string_checka(args):
-    url = args.url
-    string = args.string
-
-    parsed_url = urlparse(url=url)
-
-    domain = parsed_url.netloc
-    scheme = parsed_url.scheme
-    path = parsed_url.path
-
-    if "https" in scheme.lower():
-        conn = http.client.HTTPSConnection(domain)
-    else:
-        conn = http.client.HTTPConnection(domain)
-
-    payload = ""
-
-    headers = {
-        'Content-Type': "application/json",
-        'User-Agent': 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_7) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/98.0.4758.102 Safari/537.36'
-    }
-
-    conn.request("GET", path, payload, headers=headers)
-
-    res = conn.getresponse()
-
-    message = f"Found '{string}' at {url}"
-
-    if res.status == 200:
-        data = res.read()
-        if string.lower() in data.decode("utf-8").lower():
+            message = message.replace("Yes", "No")
             display(message=message)
-            return True
-        else:
-            display(message=message.replace("Found", "Not Found"))
+            sml(message=message)
             return False
-    else:
-        message = f"Error accessing {url}"
-        display(display(message=message))
-        return False
\ No newline at end of file
+
